# Generated by Django 4.1.3 on 2022-11-09 08:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mapbox_baselayer", "0005_auto_20191202_1840"),
    ]

    operations = [
        migrations.AlterField(
            model_name="mapbaselayer",
            name="map_box_url",
            field=models.CharField(
                blank=True,
                help_text="Mapbox or tilejson URL, starting ",
                max_length=255,
            ),
        ),
    ]
