# Generated by Django 2.2.7 on 2019-11-29 09:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mapbox_baselayer', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='baselayertile',
            name='url',
            field=models.CharField(max_length=512),
        ),
    ]
